@@ -1,5 +1,5 @@
 package Koha::Contrib::Tamil::RecordWriter::File::Marcxml;
-$Koha::Contrib::Tamil::RecordWriter::File::Marcxml::VERSION = '0.039';
+$Koha::Contrib::Tamil::RecordWriter::File::Marcxml::VERSION = '0.040';
 # ABSTRACT: XML MARC record reader
 use Moose;
 
@@ -25,7 +25,13 @@ sub begin {
     my $self = shift;
     if ( $self->valid ) {
         my $fh = $self->fh;
-        print $fh '<?xml version="1.0" encoding="UTF-8"?>', "\n", '<collection>', "\n";
+        print $fh <<EOS;
+<collection
+  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+  xsi:schemaLocation="http://www.loc.gov/MARC21/slim
+http://www.loc.gov/standards/marcxml/schema/MARC21slim.xsd"
+  xmlns="http://www.loc.gov/MARC21/slim">
+EOS
     }
 }
 
@@ -52,7 +58,10 @@ sub write {
     my $fh  = $self->fh;
     my $xml = ref($record) eq 'MARC::Record'
               ? $record->as_xml_record() : $record;
-    $xml =~ s/<\?xml version="1.0" encoding="UTF-8"\?>\n//g if $self->valid;
+    if ( $self->valid ) {
+        $xml =~ /<record.+?(<.*)<\/record>/s;
+        $xml = "<record>\n$1</record>\n" if $1;
+    }
     print $fh $xml;
 }
 
@@ -72,7 +81,7 @@ Koha::Contrib::Tamil::RecordWriter::File::Marcxml - XML MARC record reader
 
 =head1 VERSION
 
-version 0.039
+version 0.040
 
 =head1 AUTHOR
 
